/*
 * text_mark_static.c
 *
 * Copyright 2023 Jonathan Schöbel <jonathan@xn--schbel-yxa.info>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 *
 *
 */


#include <stdlib.h>

#include "status.h"


enum SH_MARK_TYPE
{
	SH_MARK_TYPE_ABS,
	SH_MARK_TYPE_REL
};

struct text_mark
{
	enum SH_MARK_TYPE type;
	size_t offset;

	size_t mark_n;
	/*@notnull@*/ struct SH_TextMark ** marks;

	/*@null@*/ struct text_mark * next;
};


static inline
/*@null@*/
/*@only@*/
struct text_mark *
text_mark_new (const enum SH_MARK_TYPE type,
               const size_t offset,
               /*@null*/ /*@out@*/ struct SH_Status * status)
	/*@globals fileSystem@*/
	/*@modifies fileSystem@*/
	/*@modifies status@*/
{
	struct text_mark * mark;

	mark = malloc (sizeof (struct text_mark));
	if (NULL == mark)
	{
		set_status (status, E_ALLOC, 3, "malloc failed");
		return NULL;
	}

	mark->type = type;
	mark->offset = offset;

	mark->mark_n = 0;
	mark->marks = malloc (0);

	mark->next = NULL;

	return mark;
}

static inline
/*@null@*/
struct text_mark *
text_mark_free (/*@only@*/ struct text_mark * mark)
{
	struct text_mark * next;

	next = mark->next;

	free (mark->marks);
	free (mark);

	return next;
}
