/*
 * validator_html.h
 *
 * Copyright 2023 Jonathan Schöbel <jonathan@xn--schbel-yxa.info>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 *
 *
 */


#ifndef SEFHT_VALIDATOR_HTML_H
#define SEFHT_VALIDATOR_HTML_H

#if !defined (SEFHT_COMPILATION)
#error "Only <sefht/sefht.h> can be included directly."
#endif

#include "validator.h"


struct HTML_TAG_DEFINITION
{
	/*@observer@*/ const char * tag;
	enum SH_VALIDATOR_TAG_TYPE type;
};

struct HTML_ATTR_DEFINITION
{
	/*@observer@*/ const char * attr;
	/*@observer@*/ const struct HTML_TAG_DEFINITION * tags;
	size_t tag_n;
};


static const struct HTML_TAG_DEFINITION HTML5_TAGS[] = {
	{"a",		SH_TAG_TYPE_NORMAL},
	{"abbr",	SH_TAG_TYPE_NORMAL},
	{"address",	SH_TAG_TYPE_NORMAL},
	{"area",	SH_TAG_TYPE_VOID},
	{"article",	SH_TAG_TYPE_NORMAL},
	{"aside",	SH_TAG_TYPE_NORMAL},
	{"audio",	SH_TAG_TYPE_NORMAL},
	{"b",		SH_TAG_TYPE_NORMAL},
	{"base",	SH_TAG_TYPE_VOID},
	{"bdi",		SH_TAG_TYPE_NORMAL},
	{"bdo",		SH_TAG_TYPE_NORMAL},
	{"blockquote",	SH_TAG_TYPE_NORMAL},
	{"body",	SH_TAG_TYPE_NORMAL},
	{"br",		SH_TAG_TYPE_VOID},
	{"button",	SH_TAG_TYPE_NORMAL},
	{"canvas",	SH_TAG_TYPE_NORMAL},
	{"caption",	SH_TAG_TYPE_NORMAL},
	{"cite",	SH_TAG_TYPE_NORMAL},
	{"code",	SH_TAG_TYPE_NORMAL},
	{"col",		SH_TAG_TYPE_VOID},
	{"colgroup",	SH_TAG_TYPE_NORMAL},
	{"data",	SH_TAG_TYPE_NORMAL},
	{"datalist",	SH_TAG_TYPE_NORMAL},
	{"dd",		SH_TAG_TYPE_NORMAL},
	{"del",		SH_TAG_TYPE_NORMAL},
	{"details",	SH_TAG_TYPE_NORMAL},
	{"dfn",		SH_TAG_TYPE_NORMAL},
	{"dialog",	SH_TAG_TYPE_NORMAL},
	{"div",		SH_TAG_TYPE_NORMAL},
	{"dl",		SH_TAG_TYPE_NORMAL},
	{"dt",		SH_TAG_TYPE_NORMAL},
	{"em",		SH_TAG_TYPE_NORMAL},
	{"embed",	SH_TAG_TYPE_VOID},
	{"fieldset",	SH_TAG_TYPE_NORMAL},
	{"figcaption",	SH_TAG_TYPE_NORMAL},
	{"figure",	SH_TAG_TYPE_NORMAL},
	{"footer",	SH_TAG_TYPE_NORMAL},
	{"form",	SH_TAG_TYPE_NORMAL},
	{"h1",		SH_TAG_TYPE_NORMAL},
	{"h2",		SH_TAG_TYPE_NORMAL},
	{"h3",		SH_TAG_TYPE_NORMAL},
	{"h4",		SH_TAG_TYPE_NORMAL},
	{"h5",		SH_TAG_TYPE_NORMAL},
	{"h6",		SH_TAG_TYPE_NORMAL},
	{"head",	SH_TAG_TYPE_NORMAL},
	{"header",	SH_TAG_TYPE_NORMAL},
	{"hgroup",	SH_TAG_TYPE_NORMAL},
	{"hr",		SH_TAG_TYPE_VOID},
	{"html",	SH_TAG_TYPE_NORMAL},
	{"i",		SH_TAG_TYPE_NORMAL},
	{"iframe",	SH_TAG_TYPE_NORMAL},
	{"img",		SH_TAG_TYPE_VOID},
	{"input",	SH_TAG_TYPE_VOID},
	{"ins",		SH_TAG_TYPE_NORMAL},
	{"kbd",		SH_TAG_TYPE_NORMAL},
	{"label",	SH_TAG_TYPE_NORMAL},
	{"legend",	SH_TAG_TYPE_NORMAL},
	{"li",		SH_TAG_TYPE_NORMAL},
	{"link",	SH_TAG_TYPE_VOID},
	{"main",	SH_TAG_TYPE_NORMAL},
	{"map",		SH_TAG_TYPE_NORMAL},
	{"mark",	SH_TAG_TYPE_NORMAL},
	{"menu",	SH_TAG_TYPE_NORMAL},
	{"meta",	SH_TAG_TYPE_VOID},
	{"meter",	SH_TAG_TYPE_NORMAL},
	{"nav",		SH_TAG_TYPE_NORMAL},
	{"noscript",	SH_TAG_TYPE_NORMAL},
	{"object",	SH_TAG_TYPE_NORMAL},
	{"ol",		SH_TAG_TYPE_NORMAL},
	{"optgroup",	SH_TAG_TYPE_NORMAL},
	{"option",	SH_TAG_TYPE_NORMAL},
	{"output",	SH_TAG_TYPE_NORMAL},
	{"p",		SH_TAG_TYPE_NORMAL},
	{"picture",	SH_TAG_TYPE_NORMAL},
	{"pre",		SH_TAG_TYPE_NORMAL},
	{"progress",	SH_TAG_TYPE_NORMAL},
	{"q",		SH_TAG_TYPE_NORMAL},
	{"rp",		SH_TAG_TYPE_NORMAL},
	{"rt",		SH_TAG_TYPE_NORMAL},
	{"ruby",	SH_TAG_TYPE_NORMAL},
	{"s",		SH_TAG_TYPE_NORMAL},
	{"samp",	SH_TAG_TYPE_NORMAL},
	{"script",	SH_TAG_TYPE_RAW_TEXT},
	{"search",	SH_TAG_TYPE_NORMAL},
	{"section",	SH_TAG_TYPE_NORMAL},
	{"select",	SH_TAG_TYPE_NORMAL},
	{"slot",	SH_TAG_TYPE_NORMAL},
	{"small",	SH_TAG_TYPE_NORMAL},
	{"source",	SH_TAG_TYPE_VOID},
	{"span",	SH_TAG_TYPE_NORMAL},
	{"strong",	SH_TAG_TYPE_NORMAL},
	{"style",	SH_TAG_TYPE_RAW_TEXT},
	{"sub",		SH_TAG_TYPE_NORMAL},
	{"summary",	SH_TAG_TYPE_NORMAL},
	{"sup",		SH_TAG_TYPE_NORMAL},
	{"table",	SH_TAG_TYPE_NORMAL},
	{"tbody",	SH_TAG_TYPE_NORMAL},
	{"td",		SH_TAG_TYPE_NORMAL},
	{"template",	SH_TAG_TYPE_TEMPLATE},
	{"textarea",	SH_TAG_TYPE_ESC_RAW_TEXT},
	{"tfoot",	SH_TAG_TYPE_NORMAL},
	{"th",		SH_TAG_TYPE_NORMAL},
	{"thead",	SH_TAG_TYPE_NORMAL},
	{"time",	SH_TAG_TYPE_NORMAL},
	{"title",	SH_TAG_TYPE_ESC_RAW_TEXT},
	{"tr",		SH_TAG_TYPE_NORMAL},
	{"track",	SH_TAG_TYPE_VOID},
	{"u",		SH_TAG_TYPE_NORMAL},
	{"ul",		SH_TAG_TYPE_NORMAL},
	{"var",		SH_TAG_TYPE_NORMAL},
	{"video",	SH_TAG_TYPE_NORMAL},
	{"wbr",		SH_TAG_TYPE_VOID},
};

static const struct HTML_ATTR_DEFINITION HTML5_ATTRS[] = {
};

#endif /* SEFHT_VALIDATOR_HTML_H */
