/*
 * test_text_mark.c
 *
 * Copyright 2023 Jonathan Schöbel <jonathan@xn--schbel-yxa.info>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 *
 *
 */


#include <check.h>
#include <limits.h>
#include <stdbool.h>
#include <stdlib.h>

#include "log.h"
#include "macro.h"
#include "status.h"


#include "text_mark_static.c"


START_TEST(test_text_mark_no_status)
{
	struct text_mark * mark;

	mark = text_mark_new (SH_MARK_TYPE_ABS, 5, NULL);
	ck_assert_ptr_ne (NULL, mark);

	ck_assert_int_eq (SH_MARK_TYPE_ABS, mark->type);
	ck_assert_int_eq (5, mark->offset);
	ck_assert_int_eq (0, mark->mark_n);
	ck_assert_ptr_ne (NULL, mark->marks);
	ck_assert_ptr_eq (NULL, mark->next);

	text_mark_free (mark);
}
END_TEST

START_TEST(test_text_mark_with_status)
{
	struct SH_Status status;
	struct text_mark * mark;

	_status_preinit (status);
	mark = text_mark_new (SH_MARK_TYPE_ABS, 5, &status);
	ck_assert_ptr_ne (NULL, mark);
	ck_assert_int_eq (status.status, UNDEFINED);

	ck_assert_int_eq (SH_MARK_TYPE_ABS, mark->type);
	ck_assert_int_eq (5, mark->offset);
	ck_assert_int_eq (0, mark->mark_n);
	ck_assert_ptr_ne (NULL, mark->marks);
	ck_assert_ptr_eq (NULL, mark->next);

	text_mark_free (mark);
}
END_TEST

Suite * test_suite (void)
{
	Suite *s;
	TCase *tc_core;

	s = suite_create ("Testsuite SeFHT Text Mark (internal) ");

	/* Core test case */
	tc_core = tcase_create ("Core");

	tcase_add_test (tc_core, test_text_mark_no_status);
	tcase_add_test (tc_core, test_text_mark_with_status);
	suite_add_tcase (s, tc_core);

	return s;
}

int main (void)
{
	int number_failed;
	Suite *s;
	SRunner *sr;

	s = test_suite ();
	sr = srunner_create (s);

	srunner_run_all (sr, CK_NORMAL);
	number_failed = srunner_ntests_failed (sr);
	srunner_free (sr);

	return (number_failed == 0) ? EXIT_SUCCESS : EXIT_FAILURE;
}

